function x = catrnd(p, dims)
% # Categorical random number generator
% ## Usage
% * `x = catrnd(p)`
% * `x = catrnd(p, dims)`
%
% ## Description
% Generates random samples distributed according to the categorical
% distribution with weights p.
%
% ## Input
% * `p`: Probabilities.
% * `dims`: Dimensions (default: `[1, 1]`).
%
% ## Outut
% * `x`: Matrix of random samples of dimension `dims`.
% 
% ## Authors
% 2021-present -- Roland Hostettler

%{
% This file is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% This file is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
% FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
% more details.
% 
% You should have received a copy of the GNU General Public License along 
% with this file. If not, see <http://www.gnu.org/licenses/>.
%}

% TODO:
% * Should add sanity checks for the dimensions of p

    %% Defaults
    narginchk(1, 2);
    if nargin < 2 || isempty(dims)
        dims = [1, 1];
    end
    
    %% Generate samples
    % Prepare
    p = p/sum(p);   % Normalize
    P = cumsum(p);  % Calculate the CDF
   
    % Sample
    u = rand(dims);
    x = zeros(dims);
    for m = 1:dims(1)
        for n = 1:dims(2)
            x(m, n) = find(u(m, n) <= P, 1, 'first');
        end
    end
end