function B = submat(A, r, c)
% # Slicing for anonymous functions
% ## Usage
% * `B = submat(A, r)`
% * `B = submat(A, r, c)`
%
% ## Description
% Function to slice the results from anonymous functions, useful when only
% a slice of the anonymous function is required.
%
% ## Input
% * `A`: N-times-M matrix (e.g., result from an anonymous function).
% * `r`: Row slice indices.
% * `c`: Column slice indices (default: `1:M`).
%
% ## Output
% * `B`: Matrix slice.
%
% ## Authors
% 2019-present -- Roland Hostettler

%{
% This file is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% This file is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
% FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
% more details.
% 
% You should have received a copy of the GNU General Public License along 
% with this file. If not, see <http://www.gnu.org/licenses/>.
%}

    narginchk(2, 3);
    [N, M] = size(A);
    if isempty(r)
        r = 1:N;
    end
    if nargin < 3 || isempty(c)
        c = 1:M;
    end
    B = A(r, c);
end
